@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::RJBS;
-our $VERSION = '0.091370';
+our $VERSION = '0.091390';
 
 # ABSTRACT: BeLike::RJBS when you build your dists
 
@@ -14,8 +14,9 @@ sub bundle_config {
   my ($self, $arg) = @_;
   my $class = (ref $self) || $self;
 
-  my $major_version;
-  $major_version = defined $arg->{version} ? $arg->{version} : 0;
+  my $major_version = defined $arg->{version} ? $arg->{version} : 0;
+  my $format        = q<{{ $major }}.{{ cldr('yyDDD') }}>
+                    . sprintf '%01u', ($ENV{N} || 0);
 
   my @plugins = Dist::Zilla::PluginBundle::Filter->bundle_config({
     bundle => '@Classic',
@@ -23,11 +24,12 @@ sub bundle_config {
   });
 
   push @plugins, (
-    [ 'Dist::Zilla::Plugin::AutoVersion' => { major => $major_version } ],
-    [ 'Dist::Zilla::Plugin::MetaJSON'    => {                         } ],
-    [ 'Dist::Zilla::Plugin::NextRelease' => {                         } ],
-    [ 'Dist::Zilla::Plugin::PodPurler'   => {                         } ],
-    [ 'Dist::Zilla::Plugin::Repository'  => {                         } ],
+    [ 'Dist::Zilla::Plugin::AutoVersion' =>
+      { major => $major_version, format => $format } ],
+    [ 'Dist::Zilla::Plugin::MetaJSON'    => {      } ],
+    [ 'Dist::Zilla::Plugin::NextRelease' => {      } ],
+    [ 'Dist::Zilla::Plugin::PodPurler'   => {      } ],
+    [ 'Dist::Zilla::Plugin::Repository'  => {      } ],
   );
 
   eval "require $_->[0]" or die for @plugins; ## no critic Carp
@@ -51,7 +53,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 0.091370
+version 0.091390
 
 =head1 DESCRIPTION
 
